@@ -19,25 +19,25 @@ class Test_DrillString(unittest.TestCase):
         adripy.create_cfg_file(TEST_CONFIG_FILENAME, [TEST_DATABASE_PATH, TEST_NEW_DATABASE_PATH])
         
         # Create a DrillTool object representing a stabilizer
-        self.pdc_bit = adripy.tiem_orbit.DrillTool(TEST_PDC_FILE)
+        self.pdc_bit = adripy.DrillTool(TEST_PDC_FILE)
 
         # Create a DrillTool object representing a stabilizer
-        self.stabilizer = adripy.tiem_orbit.DrillTool(TEST_STABILIZER_FILE)
+        self.stabilizer = adripy.DrillTool(TEST_STABILIZER_FILE)
 
         # Create a DrillTool object representing a drill pipe
-        self.drill_pipe = adripy.tiem_orbit.DrillTool(TEST_DRILLPIPE_FILE)
+        self.drill_pipe = adripy.DrillTool(TEST_DRILLPIPE_FILE)
 
         # Create a DrillTool object representing EUS
-        self.eus = adripy.tiem_orbit.DrillTool(TEST_EUS_FILE)
+        self.eus = adripy.DrillTool(TEST_EUS_FILE)
         
         # Create a DrillTool object representing a top drive
-        self.top_drive = adripy.tiem_orbit.DrillTool(TEST_TOP_DRIVE_FILE)
+        self.top_drive = adripy.DrillTool(TEST_TOP_DRIVE_FILE)
 
     def test_add_tool(self):
         """Test the DrillString.add_tool() method.
         """
         # Create a DrillString object
-        drill_string = adripy.tiem_orbit.DrillString(TEST_STRING_NAME, TEST_HOLE_FILE, TEST_EVENT_FILE)
+        drill_string = adripy.DrillString(TEST_STRING_NAME, TEST_HOLE_FILE, TEST_EVENT_FILE)
 
         # Add the DrillTool object to the DrillString object
         drill_string.add_tool(self.stabilizer)
@@ -60,7 +60,7 @@ class Test_DrillString(unittest.TestCase):
         """Test the DrillString.write_to_file() method.
         """
         # Create a DrillString object
-        drill_string = adripy.tiem_orbit.DrillString(TEST_STRING_NAME, TEST_HOLE_FILE, TEST_EVENT_FILE)
+        drill_string = adripy.DrillString(TEST_STRING_NAME, TEST_HOLE_FILE, TEST_EVENT_FILE)
 
         # Add the DrillTool objects to the DrillString object
         drill_string.add_tool(self.pdc_bit, measure='yes')
@@ -82,7 +82,7 @@ class Test_DrillString(unittest.TestCase):
         """Test the DrillString.write_to_file() method with publish=True
         """
         # Create a DrillString object
-        drill_string = adripy.tiem_orbit.DrillString(TEST_STRING_NAME, TEST_HOLE_FILE, TEST_EVENT_FILE)
+        drill_string = adripy.DrillString(TEST_STRING_NAME, TEST_HOLE_FILE, TEST_EVENT_FILE)
 
         # Add the DrillTool objects to the DrillString object
         drill_string.add_tool(self.pdc_bit, measure='yes')
@@ -124,7 +124,36 @@ class Test_DrillString(unittest.TestCase):
 
         # Read new parameters into the drill string object from a file
         string_file = os.path.join(f'<{TEST_DATABASE_NAME}>', 'drill_strings.tbl', TEST_EXISTING_STRING_NAME + '.str')
-        drill_string_from_file = adripy.tiem_orbit.DrillString.read_from_file(string_file)
+        drill_string_from_file = adripy.DrillString.read_from_file(string_file)
+        
+        # Remove some keys from the parameters dictionary
+        drill_string_from_file.parameters.pop('_Distance_from_Bit')
+
+        self.assertDictEqual(drill_string_from_file.parameters, expected_parameters)
+    
+    def test_read_string_from_file_no_dfb(self):
+        
+        expected_parameters = {
+            'Units': 'Imperial',
+            'ModelName': 'test_string',
+            'OutputName': 'test_string',
+            'Gravity': 32.187,
+            'Deviation_Deg': 0.0,
+            'Adams_Results': 'animation',
+            'Adams_Graphics': 'off',
+            'Adams_Requests': 'on',
+            'Distance_from_Bit': [],
+            'SolverDLL': 'adrill_solver',
+            'Hole_Property_File': '<example_database>\\holes.tbl\\test_hole.hol',
+            'Contact_Method': 'Subroutine',
+            'Cyl_Drag_Coeff': 1.0,
+            'Hole_Color': 'LtGray',
+            'Event_Property_File': '<example_database>\\events.tbl\\test_event.evt'
+        }
+
+        # Read new parameters into the drill string object from a file
+        string_file = os.path.join(f'<{TEST_DATABASE_NAME}>', 'drill_strings.tbl', TEST_EXISTING_STRING_NAME_NO_DFB + '.str')
+        drill_string_from_file = adripy.DrillString.read_from_file(string_file)
         
         # Remove some keys from the parameters dictionary
         drill_string_from_file.parameters.pop('_Distance_from_Bit')
@@ -146,7 +175,7 @@ class Test_DrillString(unittest.TestCase):
 
         # Read new parameters into the drill string object from a file
         string_file = os.path.join(f'<{TEST_DATABASE_NAME}>', 'drill_strings.tbl', TEST_EXISTING_STRING_NAME + '.str')
-        drill_string_from_file = adripy.tiem_orbit.DrillString.read_from_file(string_file)
+        drill_string_from_file = adripy.DrillString.read_from_file(string_file)
         
         # Get the first tool
         actual_tool = drill_string_from_file.tools[0]
@@ -171,7 +200,7 @@ class Test_DrillString(unittest.TestCase):
 
         # Read new parameters into the drill string object from a file
         string_file = os.path.join(f'<{TEST_DATABASE_NAME}>', 'drill_strings.tbl', TEST_EXISTING_STRING_NAME + '.str')
-        drill_string_from_file = adripy.tiem_orbit.DrillString.read_from_file(string_file)
+        drill_string_from_file = adripy.DrillString.read_from_file(string_file)
 
         # Get the first tool
         actual_tool = drill_string_from_file.tools[0]
@@ -196,7 +225,7 @@ class Test_DrillString(unittest.TestCase):
 
         # Read new parameters into the drill string object from a file
         string_file = os.path.join(f'<{TEST_DATABASE_NAME}>', 'drill_strings.tbl', TEST_EXISTING_STRING_NAME + '.str')
-        drill_string_from_file = adripy.tiem_orbit.DrillString.read_from_file(string_file)
+        drill_string_from_file = adripy.DrillString.read_from_file(string_file)
         
         # Get the first tool
         actual_tool = drill_string_from_file.tools[-1]
@@ -217,7 +246,7 @@ class Test_DrillString(unittest.TestCase):
 
         # Read new parameters into the drill string object from a file
         string_file = os.path.join(f'<{TEST_DATABASE_NAME}>', 'drill_strings.tbl', TEST_EXISTING_STRING_NAME + '.str')
-        drill_string_from_file = adripy.tiem_orbit.DrillString.read_from_file(string_file)
+        drill_string_from_file = adripy.DrillString.read_from_file(string_file)
         
         # Get the first tool
         bit = drill_string_from_file.tools[0]['DrillTool']
@@ -243,7 +272,7 @@ class Test_DrillString(unittest.TestCase):
 
         # Read new parameters into the drill string object from a file
         string_file = os.path.join(f'<{TEST_DATABASE_NAME}>', 'drill_strings.tbl', TEST_EXISTING_STRING_NAME + '.str')
-        drill_string_from_file = adripy.tiem_orbit.DrillString.read_from_file(string_file)
+        drill_string_from_file = adripy.DrillString.read_from_file(string_file)
         
         # Get the first tool
         bit = drill_string_from_file.tools[-1]['DrillTool']
@@ -266,7 +295,7 @@ class Test_DrillString(unittest.TestCase):
 
         # Read new parameters into the drill string object from a file
         string_file = os.path.join(f'<{TEST_DATABASE_NAME}>', 'drill_strings.tbl', TEST_EXISTING_STRING_NAME + '.str')
-        drill_string_from_file = adripy.tiem_orbit.DrillString.read_from_file(string_file)
+        drill_string_from_file = adripy.DrillString.read_from_file(string_file)
         
         actual_n_tools = len(drill_string_from_file.tools)
 
@@ -277,10 +306,10 @@ class Test_DrillString(unittest.TestCase):
         """Tests that DrillString.get_tool() returns the correct value.
         """
         # Create a DrillString object
-        drill_string = adripy.tiem_orbit.DrillString(TEST_STRING_NAME, TEST_HOLE_FILE, TEST_EVENT_FILE)
+        drill_string = adripy.DrillString(TEST_STRING_NAME, TEST_HOLE_FILE, TEST_EVENT_FILE)
 
         # Define a new stabilizer object
-        different_stabilizer  = adripy.tiem_orbit.DrillTool(TEST_STABILIZER_FILE)
+        different_stabilizer  = adripy.DrillTool(TEST_STABILIZER_FILE)
 
         # Add the DrillTool objects to the DrillString object
         drill_string.add_tool(self.pdc_bit, measure='yes')
@@ -298,10 +327,10 @@ class Test_DrillString(unittest.TestCase):
         """Tests that DrillString.get_tool() returns the correct value.
         """
         # Create a DrillString object
-        drill_string = adripy.tiem_orbit.DrillString(TEST_STRING_NAME, TEST_HOLE_FILE, TEST_EVENT_FILE)
+        drill_string = adripy.DrillString(TEST_STRING_NAME, TEST_HOLE_FILE, TEST_EVENT_FILE)
         
         # Define a new stabilizer object
-        different_stabilizer  = adripy.tiem_orbit.DrillTool(TEST_STABILIZER_FILE)
+        different_stabilizer  = adripy.DrillTool(TEST_STABILIZER_FILE)
         
         # Add the DrillTool objects to the DrillString object
         drill_string.add_tool(self.pdc_bit, measure='yes')
@@ -311,7 +340,7 @@ class Test_DrillString(unittest.TestCase):
         drill_string.add_tool(self.eus, joints=20, group_name='equivalent_pipe', equivalent=True)
         drill_string.add_tool(self.top_drive)
 
-        got_tool = drill_string.get_tool('stabilizer', instance='last')
+        got_tool = drill_string.get_tool('stabilizer', index=-1)
 
         self.assertEqual(got_tool, different_stabilizer)  
 
@@ -319,10 +348,10 @@ class Test_DrillString(unittest.TestCase):
         """Tests that DrillString.get_tool() returns the correct value.
         """
         # Create a DrillString object
-        drill_string = adripy.tiem_orbit.DrillString(TEST_STRING_NAME, TEST_HOLE_FILE, TEST_EVENT_FILE)
+        drill_string = adripy.DrillString(TEST_STRING_NAME, TEST_HOLE_FILE, TEST_EVENT_FILE)
         
         # Define a new stabilizer object
-        different_stabilizer  = adripy.tiem_orbit.DrillTool(TEST_STABILIZER_FILE)
+        different_stabilizer  = adripy.DrillTool(TEST_STABILIZER_FILE)
         
         # Add the DrillTool objects to the DrillString object
         drill_string.add_tool(self.pdc_bit, measure='yes')
@@ -332,7 +361,7 @@ class Test_DrillString(unittest.TestCase):
         drill_string.add_tool(self.eus, joints=20, group_name='equivalent_pipe', equivalent=True)
         drill_string.add_tool(self.top_drive)
 
-        got_tool = drill_string.get_tool('stabilizer', instance=1)
+        got_tool = drill_string.get_tool('stabilizer', index=0)
 
         self.assertEqual(got_tool, self.stabilizer)  
 
@@ -340,10 +369,10 @@ class Test_DrillString(unittest.TestCase):
         """Tests that DrillString.get_tool() returns the correct value.
         """
         # Create a DrillString object
-        drill_string = adripy.tiem_orbit.DrillString(TEST_STRING_NAME, TEST_HOLE_FILE, TEST_EVENT_FILE)
+        drill_string = adripy.DrillString(TEST_STRING_NAME, TEST_HOLE_FILE, TEST_EVENT_FILE)
         
         # Define a new stabilizer object
-        different_stabilizer  = adripy.tiem_orbit.DrillTool(TEST_STABILIZER_FILE)
+        different_stabilizer  = adripy.DrillTool(TEST_STABILIZER_FILE)
         
         # Add the DrillTool objects to the DrillString object
         drill_string.add_tool(self.pdc_bit, measure='yes')
@@ -353,7 +382,7 @@ class Test_DrillString(unittest.TestCase):
         drill_string.add_tool(self.eus, joints=20, group_name='equivalent_pipe', equivalent=True)
         drill_string.add_tool(self.top_drive)
 
-        got_tool = drill_string.get_tool('stabilizer', instance=2)
+        got_tool = drill_string.get_tool('stabilizer', index=1)
 
         self.assertEqual(got_tool, different_stabilizer)  
 
@@ -363,7 +392,7 @@ class Test_DrillString(unittest.TestCase):
         """
         expected_joints = 100
         # Create a DrillString object
-        drill_string = adripy.tiem_orbit.DrillString(TEST_STRING_NAME, TEST_HOLE_FILE, TEST_EVENT_FILE)
+        drill_string = adripy.DrillString(TEST_STRING_NAME, TEST_HOLE_FILE, TEST_EVENT_FILE)
 
         # Add the DrillTool objects to the DrillString object
         drill_string.add_tool(self.pdc_bit, measure='yes')
@@ -385,7 +414,7 @@ class Test_DrillString(unittest.TestCase):
         """
         expected_joints = 100
         # Create a DrillString object
-        drill_string = adripy.tiem_orbit.DrillString(TEST_STRING_NAME, TEST_HOLE_FILE, TEST_EVENT_FILE)
+        drill_string = adripy.DrillString(TEST_STRING_NAME, TEST_HOLE_FILE, TEST_EVENT_FILE)
 
         # Add the DrillTool objects to the DrillString object
         drill_string.add_tool(self.pdc_bit, measure='yes')
@@ -405,7 +434,7 @@ class Test_DrillString(unittest.TestCase):
         """Tests that DrillString.get_bha_length() returns the correct length.
         """
         # Create a DrillString object
-        drill_string = adripy.tiem_orbit.DrillString(TEST_STRING_NAME, TEST_HOLE_FILE, TEST_EVENT_FILE)
+        drill_string = adripy.DrillString(TEST_STRING_NAME, TEST_HOLE_FILE, TEST_EVENT_FILE)
 
         # Add the DrillTool objects to the DrillString object
         drill_string.add_tool(self.pdc_bit, measure='yes')
